Crate forge_client

Crate forge_client 

forge-client

MCP client connections to downstream servers for the Forgemax Code Mode Gateway.

Provides McpClient for connecting to individual MCP servers over stdio or HTTP transports, and RouterDispatcher for routing tool calls to the correct downstream server.

Re-exports

pub use circuit_breaker::CircuitBreakerConfig;
pub use circuit_breaker::CircuitBreakerDispatcher;
pub use circuit_breaker::CircuitBreakerResourceDispatcher;
pub use router::RouterDispatcher;
pub use router::RouterResourceDispatcher;
pub use timeout::TimeoutDispatcher;
pub use timeout::TimeoutResourceDispatcher;

Modules

circuit_breaker
Circuit breaker wrapper for tool dispatchers.
router
Router dispatcher for routing tool calls to the correct downstream MCP client.
timeout
Per-server timeout wrapper for tool dispatchers.

Structs

McpClient
A client connection to a single downstream MCP server.
ResourceInfo
Information about a resource discovered from a downstream server.
ToolInfo
Information about a tool discovered from a downstream server.

Enums

TransportConfig
Configuration for connecting to a downstream MCP server.